@@ -81,7 +81,7 @@ typedef struct {
 
     /* private resources. */
     Boolean set_values_area_cleared; /* Remember if we need to unhighlight. */
-    GC norm_gc;			/* noral color gc. */
+    GC norm_gc;			/* normal color gc. */
     GC rev_gc;			/* reverse color gc. */
     GC norm_gray_gc;		/* Normal color (grayed out) gc. */
     GC invert_gc;		/* gc for flipping colors. */
